/**
 * @author Alexei Mikhailishin miha@oc3.ru
 */
oc3board.User =
{
   //
   // variables
   //
   
   logged: new Boolean(false),
   list:   null,
   user:   null,
   
   //
   // user information
   //
   
   updateUser: function(url)
   {
      var req = new XMLHttpRequest();
      req.open("GET", url, true);
      req.onreadystatechange = function()
      {
         if (req.readyState == 4)
         {
            if (req.status == 200)
            {
               oc3board.User.userUpdated(req.responseText);
            } else
            {
               oc3board.User.userNotUpdated();  
            }
         }   
      }
      req.send(null);      
   },
   
   userUpdated: function(text)
   {
      var parser = new DOMParser();
      var xmldoc = parser.parseFromString(text, "text/xml");
      var userNode = xmldoc.getElementsByTagName("user").item(0);
      this.logged = userNode != null && userNode.childElementCount > 0;
      oc3board.User.updateIcon();
      if (!this.logged)
      {
         oc3board.User.userNotUpdated();
         return;
      }      
      
      this.user = new Object();
      var userInfoNode = userNode.firstElementChild;
      while (userInfoNode)
      {         
         this.user[userInfoNode.nodeName] = userInfoNode.textContent;         
         userInfoNode = userInfoNode.nextElementSibling;
      }
      
      // enabling back Publish button during login
      //var menu = document.getElementById("oc3board-publish-document");
      //menu.setAttribute("disabled", false);
      
      var button = document.getElementById("oc3board-about");
      button.setAttribute("label", this.user["login"]); 
   },
   
   userNotUpdated: function()
   {
      var strbundle = document.getElementById("oc3board-strings");
      var localizedString = strbundle.getString("oc3board.aboutBox");
      
      // disabling of Publish button during logout
      //var menu = document.getElementById("oc3board-publish-document");
      //menu.setAttribute("disabled", true);
      
      var button = document.getElementById("oc3board-about");
      button.setAttribute("label", localizedString); 
   },
   
   //
   // recent files list
   //
   
   updateList: function(url)
   {
      var req = new XMLHttpRequest();
      req.open("GET", url, true);
      req.onreadystatechange = function()
      {
         if (req.readyState == 4)
         {
            if (req.status == 200)
            {
               oc3board.User.listUpdated(req.responseText);
            } else
            {
               oc3board.User.listNotUpdated();  
            }
         }   
      }
      req.send(null);  
   },
   
   listUpdated: function(text)
   {
      var parser = new DOMParser();
      var xmldoc = parser.parseFromString(text, "text/xml");
      var filesNode = xmldoc.getElementsByTagName("files").item(0);      
      if (filesNode == null || filesNode.childElementCount == 0)
      {
         oc3board.User.listNotUpdated();
         return;
      }      
      
      this.list = new Array();
      var fileNode = filesNode.firstElementChild;
      var counter = 0;
      while (fileNode)
      {         
         var children = fileNode.children;
                  
         this.list[counter] = new Object();
         for (var i = 0; i < children.length; i++) 
         {            
            this.list[counter][children[i].nodeName] = children[i].textContent;
         };
         
         //this.list[counter]["file"] = children[1].textContent;
         //this.list[counter]["link"] = children[3].textContent;

         fileNode = fileNode.nextElementSibling;
         counter++;
      }
      
      oc3board.User.rebuildListMent();
      
      var menu = document.getElementById("oc3board-recent-documents-menu");
      menu.setAttribute("disabled", false);
   },
   
   listNotUpdated: function()
   {
      var menu = document.getElementById("oc3board-recent-documents-menu");
      menu.setAttribute("disabled", true);
   },
   
   //
   // menu for recent-files
   //
   
   createMenuItem: function(aId, aLabel, aTag, aImage)
   {
      const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
      var item = document.createElementNS(XUL_NS, "menuitem"); // create a new XUL menuitem
      item.setAttribute("id", aId);
      item.setAttribute("label", aLabel);
      item.setAttribute("tag", aTag);
      if (aImage != null)
      {
         item.setAttribute("class", "menuitem-iconic");
         item.setAttribute("image", aImage);
      }
      return item;
   },

   createMenuSeparator: function()
   {
      const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
      var item = document.createElementNS(XUL_NS, "menuseparator"); // create a new XUL menuseparator
      return item;
   },   
   
   rebuildListMent: function()
   {
      var menu = document.getElementById("oc3board-recent-documents-menupopup");
      while(menu.hasChildNodes())
      {
         menu.removeChild(menu.firstChild);
      }
      
      var counter = 0;
      for (val in this.list)
      {
         var filename = this.list[val]["name"];
         var extensionIndex = filename.lastIndexOf('.');
         var extensionless = filename.substr(0, extensionIndex); 
         menu.appendChild(oc3board.User.createMenuItem("oc3board-recent-document-" + counter.toString(), extensionless, this.list[val]["link"], "chrome://oc3board/skin/icon-document.png"));       
         counter++;
      }
      
      var strbundle = document.getElementById("oc3board-strings");
      var localizedString = strbundle.getString("oc3board.recentDocumentAll");
      
      menu.appendChild(oc3board.User.createMenuSeparator());
      menu.appendChild(oc3board.User.createMenuItem("oc3board-recent-document-all", localizedString, "", "chrome://oc3board/skin/icon-document-all.png"));
   },
   
   //
   // common interface
   //
   
   update: function()
   {
      oc3board.User.updateUser("http://oc3.ru/products/oc3board2/interface/user.php");
      oc3board.User.updateList("http://oc3.ru/products/oc3board2/interface/list.php?xml");
   },
   
   updateIcon: function()
   {
      var button = document.getElementById("oc3board-toolbar-button");
      button.setAttribute("image", this.logged ? "chrome://oc3board/skin/toolbar-button.png" : "chrome://oc3board/skin/toolbar-button-offline.png");      
   }
}